Module circular_buff

Module circular_buff 

Structs

CalcExpression
A simple expression evaluator supporting variables A and B, numeric literals, comparison and logical operators.
CircularBuffProcessor
CircularBuff processor: maintains ring buffer state, emits captured arrays on trigger.
CircularBuffer
Circular buffer state for pre/post-trigger capture.

Enums

BufferStatus
Status of the circular buffer.
TriggerCondition
Trigger condition for circular buffer.