pub struct CalcExpression { /* private fields */ }Expand description
A simple expression evaluator supporting variables A and B, numeric literals, comparison and logical operators.
Parsed into reverse-polish notation (RPN) using shunting-yard.
Implementations
Sourceimpl CalcExpression
impl CalcExpression
Sourcepub fn parse(expr: &str) -> Option<CalcExpression>
pub fn parse(expr: &str) -> Option<CalcExpression>
Parse an infix expression into RPN.
Supports: A, B (variables), numeric literals (including decimals and negatives at start or after open paren), >, <, >=, <=, ==, !=, &&, ||, !, parentheses.