pub struct TimeSeriesData {
pub values: Vec<f64>,
}Expand description
Shared data pushed from a plugin processor to a TS port driver.
values length must match the channel count configured on the driver.
Fields
values: Vec<f64>Auto Trait Implementations
impl Freeze for TimeSeriesData
impl RefUnwindSafe for TimeSeriesData
impl Send for TimeSeriesData
impl Sync for TimeSeriesData
impl Unpin for TimeSeriesData
impl UnsafeUnpin for TimeSeriesData
impl UnwindSafe for TimeSeriesData