pub struct NetcdfWriter { /* private fields */ }Expand description
NetCDF-3 file writer.
Because netcdf3::FileWriter is !Send (uses Rc internally), we cannot
store it as a field on a Send + Sync struct. Instead we buffer frame data
in memory and materialise the FileWriter only inside close_file(), where
it is created, used, and dropped within a single method call. The same
approach is used for read_file() with FileReader.
Implementations
Sourceimpl NetcdfWriter
impl NetcdfWriter