pub fn set_num_threads(n: usize)
Set the number of rayon worker threads before the pool is first used.
Must be called before any plugin processes an array. Has no effect if the pool has already been initialized.