Generic passthrough plugin processor.
Used as a stub for plugin types that are not yet fully implemented but need to appear in the OPI with correct metadata.
Structs
- Passthrough
Processor - A no-op plugin processor that passes arrays through unchanged.